;;; Character set conversions

;; Copyright (C) 2004, 2005 Brailcom, o.p.s.

;; Author: Milan Zamazal <pdm@brailcom.org>

;; COPYRIGHT NOTICE

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
;; for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.


(require 'fileio)


(define (recode string from to)
  (with-temp-file-data (tmpfile string)
    (system (format nil "recode -f %s..%s %s" from to tmpfile))
    (read-file tmpfile)))

(define (recode-utf8->current string)
  (let ((coding (current-voice-coding)))
    (if (eq? coding 'utf-8)
        string
        (recode string 'utf-8 coding))))


(provide 'recode)
